package com.mt.wms.empty.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.google.gson.JsonObject;
import com.mt.wms.core.base.BaseController;
import com.mt.wms.core.constants.CommonConstant;
import com.mt.wms.core.dal.entity.ParEleValue;
import com.mt.wms.core.dal.service.ParEleValueServiceBiz;
import com.mt.wms.core.vo.R;
import com.mt.wms.empty.params.ElectricQueryParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.groups.Default;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.temporal.ChronoUnit;
import java.util.List;

/**
 * @Author: liguanghao
 * @Date: 2021/12/16 11:20
 * @Version 1.0
 */
@RestController
@RequestMapping(CommonConstant.API_MODULE_BASE + "electric")
@Slf4j
@Api(value = "电能消耗相关接口", tags = "电能消耗相关接口", hidden = false)
public class ElectricController extends BaseController {

    @Autowired
    private ParEleValueServiceBiz parEleValueServiceBiz;

    @PostMapping(value = "eletric")
    @ApiOperation(value = "根据窑炉id获取电能消耗情况")
    private R<String> list(@Validated({Default.class}) @RequestBody ElectricQueryParam electricQueryParam) {
        Long kiln = electricQueryParam.getKilnId();
        //窑炉id为0代表全部
        if (kiln==0){

        }else {
            JSONObject jsonObject=new JSONObject();
            //指定时间节点
            LocalDate timeDate = electricQueryParam.getTime().toLocalDate();
            LocalDateTime timeStart = LocalDateTime.of(timeDate, LocalTime.MIN);
            LocalDateTime timeEnd = LocalDateTime.of(timeDate, LocalTime.MAX);
            //当前时间节点
            LocalDateTime todayStart = LocalDateTime.of(LocalDate.now(), LocalTime.MIN);
            LocalDateTime todayEnd = LocalDateTime.of(LocalDate.now(), LocalTime.MAX);

            //总电能消耗
            List<ParEleValue> todayEleValueList = parEleValueServiceBiz.list(new QueryWrapper<ParEleValue>()
                    .eq("kiln_id", kiln)
                    .between("create_time", todayStart, todayEnd)
                    .orderByDesc("create_time"));
            Float countEleValue = todayEleValueList.get(0).getTotalBat();
            jsonObject.put("countEle",countEleValue);

            //昨日电能消耗
            LocalDateTime yesterdayStart = LocalDateTime.of(LocalDate.now().plus(1, ChronoUnit.DAYS), LocalTime.MIN);
            LocalDateTime yesterdayEnd = LocalDateTime.of(LocalDate.now().plus(1, ChronoUnit.DAYS), LocalTime.MAX);
            List<ParEleValue> yesterdayEleValueList = parEleValueServiceBiz.list(new QueryWrapper<ParEleValue>()
                    .eq("kiln_id", kiln)
                    .between("create_time", yesterdayStart, yesterdayEnd)
                    .orderByAsc("create_time"));
            Float yesterdayTotalBat= yesterdayEleValueList.get(yesterdayEleValueList.size()-1).getTotalBat()-yesterdayEleValueList.get(0).getTotalBat();
            jsonObject.put("yesterdayCountEle",yesterdayTotalBat);

            //指定日期当天的电能消耗
            if (electricQueryParam.getDateType()==1){
                List<ParEleValue> dateEleValueList = parEleValueServiceBiz.list(new QueryWrapper<ParEleValue>()
                        .eq("kiln_id", kiln)
                        .between("create_time", timeStart, timeEnd)
                        .orderByAsc("create_time"));
                //总耗电量
                Float dateCountEle=0F;
                if (dateEleValueList.size()!=0){
                    dateCountEle= dateEleValueList.get(dateEleValueList.size()-1).getTotalBat()-dateEleValueList.get(0).getTotalBat();
                }
                jsonObject.put("dateCountEle",dateCountEle);
                //分时消耗量
                for (int i = 0; i < dateEleValueList.size() - 1; ++i) {
                    // TODO: 2021/12/16
                    float eleValue = dateEleValueList.get(i).getTotalBat() - dateEleValueList.get(i - 1).getTotalBat();
                }
            }
        }
        return null;
    }
}
